*DECK THMTRS
      SUBROUTINE THMTRS(IMPX,IC,JC,KC,XBURN,HX,HY,HZ,DTIME,CFLUX,POROS,
     > NFU,NFD,NDTOT,SASS,FCOOL,FFUEL,ACOOL,HD,PCH,RGG,RIG,RC,MAXITC,
     > MAXIT1,MAXITL,ERMAXT,ERMAXC,TIN0,POUT0,SPDIN,TINLET,POULET,
     > FRACPU,ICONDF,NCONDF,KCONDF,UCONDF,ICONDC,NCONDC,KCONDC,UCONDC,
     > IHGAP,KHGAP,IHCONV,KHCONV,WTEFF,IFRCDI,ISUBM,FRO,POW,VELOT0,
     > DCOOLI,PREST0,ENTHT0,TEMPT0,DLIQT0,TCOMB,DCOOL,TCOOL,TSURF,
     > VELOT,PREST,ENTHT,TEMPT,TCENTT,DLIQT,PINLET)
*
*-----------------------------------------------------------------------
*
*Purpose:
* driver of the transient thermal-hydraulics module for a single time
* iteration
*
*Copyright:
* Copyright (C) 2013 Ecole Polytechnique de Montreal.
*
*Author(s): P. Gallet and A. Hebert
*
*Parameters: input
* IMPX    printing index (=0 for no print).
* IC      number of meshes along X direction.
* JC      number of meshes along Y direction.
* KC      number of meshes along Z direction (channel direction).
* XBURN   burnup distribution in MWday/tonne.
* HX      X-directed mesh widths.
* HY      Y-directed mesh widths.
* HZ      Z-directed mesh widths.
* DTIME   time step in s.
* CFLUX   critical heat flux in W/m^2.
* POROS   oxyde porosity.
* NFU     number of active fuel rods in the fuel bundle.
* NFD     number of discretisation points in fuel regions.
* NDTOT   number of total discretization points in the the fuel
*         pellet and the cladding.
* SASS    assembly surface in m^2.
* FCOOL   power density fraction in coolant.
* FFUEL   power density fraction in fuel.
* ACOOL   assembly coolant cross section in m^2.
* HD      hydraulic diameter of one assembly in m.
* PCH     heating perimeter in m.
* RGG     external clad rod radius in m.
* RIG     internal clad rod radius in m.
* RC      fuel pellet radius in m.
* MAXITC  maximum number of flow iterations.
* MAXIT1  maximum number of conduction iterations.
* MAXITL  maximum number of center-pellet iterations.
* ERMAXT  convergence criterion for temperature in fuel pin in K.
* ERMAXC  convergence criterion for coolant parameters (relative error).
* TIN0    inlet coolant temperature at t-1 in K.
* POUT0   outlet coolant pressure at t-1 in Pa.
* SPDIN   inlet flow velocity at t in m/s.
* TINLET  inlet temperature at t in K.
* POULET  outlet pressure at t in Pa.
* FRACPU  plutonium fraction in fuel.
* ICONDF  fuel conductivity flag (0=Stora-Chenebault or COMETHE/
*         1=user-provided polynomial + inverse term).
* NCONDF  degree of user-provided fuel conductivity polynomial.
* KCONDF  polynomial coefficients for fuel conductivity in W/m/K^(k+1)
*         (except for the two last coefficients which belongs to the
*         inverse term).
* UCONDF  required unit of temperature in polynomial for fuel
*         conductivity (KELVIN or CELSIUS).
* ICONDC  clad conductivity flag (0=default/1=user-provided
*         polynomial).
* NCONDC  degree of user-provided clad conductivity polynomial.
* KCONDC  polynomial coefficients for clad conductivity in W/m/K^(k+1).
* UCONDC  required unit of temperature in polynomial for clad
*         conductivity (KELVIN or CELSIUS).
* IHGAP   flag indicating HGAP chosen (0=default/1=user-provided).
* KHGAP   fixed user-provided HGAP value in W/m^2/K.
* IHCONV  flag indicating HCONV chosen (0=default/1=user-provided).
* KHCONV  fixed user-provided HCONV value in W/m^2/K.
* WTEFF   surface temperature's weighting factor in effective fuel
*         temperature.
* IFRCDI  flag indicating if average approximation is forced during
*         fuel conductivity evaluation (0=default/1=average
*         approximation forced).
* ISUBM   subcooling model (0: one-phase; 1: Bowring model; 2: Saha-
*         Zuber model).
* FRO     radial power form factors.
* POW     power distribution at t in W.
* VELOT0  coolant mass flux distribution in the reactor at t-1 in kg/m^2/s.
* DCOOLI  density distribution in the reactor at t-1 in kg/m3.
* PREST0  pressure distribution in the reactor at t-1 in Pa.
* ENTHT0  enthalpy distribution in the reactor at t-1 in J/kg.
* TEMPT0  temperature distribution in the fuel rod at t-1 in K.
* DLIQT0  coolant liquid density distribution at t-1 in kg/m^3.
*
*Parameters: output
* TCOMB   averaged fuel temperature distribution in K.
* DCOOL   averaged coolant density distribution in g/cc.
* TCOOL   averaged coolant temperature distribution in K.
* TSURF   surface fuel temperature distribution in K.
* VELOT   coolant mass flux distribution in the reactor at t in kg/m^2/s.
* PREST   coolant pressure distribution in the reactor at t in Pa.
* ENTHT   coolant enthalpy distribution in the reactor at t in J/kg.
* TEMPT   temperature distribution in the fuel rod at t in K.
* TCENTT  center fuel pellet temperature distribution at t in K.
* DLIQT   coolant liquid density distribution at t in kg/m^3.
* PINLET  inlet pressure in Pa.
*
*-----------------------------------------------------------------------
*
*----
*  SUBROUTINE ARGUMENTS
*----
      INTEGER IMPX,IC,JC,KC,NFU,NFD,NDTOT,MAXITC,MAXIT1,MAXITL
      REAL XBURN(IC,JC,KC),HX(IC),HY(JC),HZ(KC),DTIME,CFLUX,POROS,SASS,
     > FFUEL,ACOOL,HD,PCH,RGG,RIG,RC,ERMAXT,ERMAXC,TIN0,FCOOL,POUT0,
     > SPDIN,TINLET,POULET,FRACPU,KCONDF(NCONDF+3),KCONDC(NCONDC+1),
     > KHGAP,KHCONV,WTEFF,FRO(NFD-1),POW(IC,JC,KC),VELOT0(IC,JC,KC),
     > DCOOLI(IC,JC,KC),PREST0(IC,JC,KC),ENTHT0(IC,JC,KC),
     > TEMPT0(IC,JC,KC,NDTOT),DLIQT0(IC,JC,KC),TCOMB(IC,JC,KC),
     > DCOOL(IC,JC,KC),TCOOL(IC,JC,KC),TSURF(IC,JC,KC),
     > VELOT(IC,JC,KC),PREST(IC,JC,KC),ENTHT(IC,JC,KC),
     > TEMPT(IC,JC,KC,NDTOT),TCENTT(IC,JC,KC),DLIQT(IC,JC,KC),PINLET
      CHARACTER UCONDF*12,UCONDC*12
*----
*  LOCAL VARIABLES
*----
      PARAMETER(KMAXO=100,MAXNPO=40,PES=9.81)
      REAL ENT(4),RHOINL,MFLXIN,RHOIN0,MFLXIN0,HINLET,HINLE0,MUIN,
     > DV(IC,JC,KC),PARAM1,PARAM2,PARAM3,ERRG,ERRP,ERRH,ERR,DELTH,
     > HMINF,POWLIN(IC,JC,KC),PHI(IC,JC,KC),MUT(IC,JC,KC),
     > RESM(IC,JC,KC),RESP(IC,JC,KC),RESH(IC,JC,KC),QFUEL(IC,JC,KC),
     > QCOOL(IC,JC,KC),TC1,HCONV(IC,JC,KC),HC(KC),AGM(KC),PC(KC),
     > TSAT,PHIC(KC),TP(KC),TLC(KC),VC(KC),HZC(KC),XFL(KC),EPS(KC),
     > XTH(KC),TB,HGSAT,TCLAD(IC,JC,KC),RAY(3),MFLXT0(IC,JC,KC),
     > MFLXT(IC,JC,KC),S(KC),ENTH(KC),SAH(KC),K11
      REAL TRE10(MAXNPO),TRE11(MAXNPO),XX2(MAXNPO),XX3(MAXNPO),ZF(2)
      CHARACTER HSMG*131
      REAL XS(4)
      DATA XS/-0.861136,-0.339981,0.339981,0.861136/
*----
*  CAKCUlATE THE INVERSE TIME STEP
*----
      IF(DTIME.EQ.0.0) THEN
        CALL XABORT('THMTRS: TIME STEP NOT DEFINED')
      ELSE
        DTINV=1.0/DTIME
      ENDIF
*----
*  COMPUTE THE INLET FLOW ENTHALPY AND MASS FLOW RATE
*----
      CALL THMSAT(POULET,TSAT)
      IF(TINLET.GT.TSAT) THEN
         WRITE(HSMG,'(28HTHMTRS: OUTLET TEMPERATURE (,1P,E12.4,
     1   40H K) GREATER THAN SATURATION TEMPERATURE.)') TINLET
         CALL XABORT(HSMG)
      ENDIF
      CALL THMPT(POUT0,TIN0,RHOIN0,HINLE0,R3,R4,R5)
      MFLXIN0=SPDIN*RHOIN0
      CALL THMPT(POULET,TINLET,RHOINL,HINLET,R3,MUIN,CPVIN)
      MFLXIN=SPDIN*RHOINL
*----
*  LOOP OVER REACTOR CHANNELS
*----
      IF(NDTOT.GT.MAXNPO) CALL XABORT('THMTRS: MAXNPO OVERFLOW')
      DO 10 I=1,IC
      DO 10 J=1,JC
      IF(POW(I,J,(KC+1)/2).GT.0.0) THEN
*----
*  MAIN LOOP ALONG THE 1D CHANNEL.
        DO K=1,KC
*----
*  COMPUTE THE LINEAR POWER, THE VOLUMIC POWER, THE THERMAL EXCHANGE
*  COEFFICIENT OF THE GAP AND THE THERMAL HEAT FLUX ALONG THE CHANNEL
*----
          DV(I,J,K)=HX(I)*HY(J)*HZ(K)
*         linear power in W/m.
          POWLIN(I,J,K)=(POW(I,J,K)/DV(I,J,K))*SASS/REAL(NFU)
*         volumic power in W/m^3.
          QFUEL(I,J,K)=POW(I,J,K)*FFUEL/DV(I,J,K)
          QCOOL(I,J,K)=POW(I,J,K)*FCOOL/DV(I,J,K)
*----
*  INITIALIZATION OF THE THERMO-HYDRAULICAL PROPERTIES OF THE FLUID
*----
          DCOOL(I,J,K)=DCOOLI(I,J,K)
          MUT(I,J,K)=MUIN
          VELOT(I,J,K)=VELOT0(I,J,K)
          MFLXT0(I,J,K)=DCOOLI(I,J,K)*VELOT(I,J,K)
          MFLXT(I,J,K)=MFLXT0(I,J,K)
          PREST(I,J,K)=PREST0(I,J,K)
          ENTHT(I,J,K)=ENTHT0(I,J,K)
          DLIQT(I,J,K)=DLIQT0(I,J,K)
          DO L=1,NDTOT
            TEMPT(I,J,K,L)=TEMPT0(I,J,K,L)
          ENDDO
          RESM(I,J,K)=MFLXT(I,J,K)
          RESP(I,J,K)=PREST(I,J,K)
          RESH(I,J,K)=ENTHT(I,J,K)
        ENDDO
      ENDIF
   10 CONTINUE
*----
*  LOOP OVER REACTOR CHANNELS
*----
      RAY(1)=RC
      RAY(2)=RIG
      RAY(3)=RGG
      DO 50 I=1,IC
      DO 50 J=1,JC
      IF(POW(I,J,(KC+1)/2).GT.0.0) THEN
*----
*  ITERATIVE PROCEDURE FOR EACH CHANNEL
*----
        DO K=1,KC
           XFL(K)=0.0
           EPS(K)=0.0
           XTH(K)=0.0
           XFL(K)=0.0
           MFLXT(I,J,K)=0.0
           S(K)=1.0
        ENDDO
        KMIN=1
        DO K=1,KC
          IF(POW(I,J,K).NE.0.0) THEN
            KMIN=K
            EXIT
          ENDIF
        ENDDO
        ITERC=0
   20   ITERC=ITERC+1
        IF(ITERC.GT.MAXITC) THEN
           CALL XABORT('THMTRS: CONVERGENCE FAILURE IN FLOW CALCULAT'//
     >     'ION.')
        ENDIF
*----
*  MAIN LOOP ALONG THE 1D CHANNEL.
*----
        DO K=KMIN,KC
          IF(POW(I,J,K).EQ.0.0) CYCLE
*----
*  SOLVE THE CONDUCTION EQUATIONS INSIDE THE FUEL ROD
*----
          DO L=1,NDTOT-1
            TRE10(L)=TEMPT0(I,J,K,L)
            TRE11(L)=TEMPT(I,J,K,L)
          ENDDO
          TSCLAD=TEMPT(I,J,K,NDTOT)
          CALL THMROD(IMPX,NFD,NDTOT-1,MAXIT1,MAXITL,ERMAXT,DTINV,
     1    RAY,TRE10,TRE11,QFUEL(I,J,K),FRO,TSCLAD,POWLIN(I,J,K),
     2    XBURN(I,J,K),POROS,FRACPU,ICONDF,NCONDF,KCONDF,UCONDF,
     3    ICONDC,NCONDC,KCONDC,UCONDC,IHGAP,KHGAP,IFRCDI,TC1,XX2,
     4    XX3,ZF)
*----
*  COMPUTE THE HEAT FLUX FROM CLAD TO COOLANT IN W/m^2
*----
          PHI(I,J,K)=(ZF(1)-TSCLAD*ZF(2))/RAY(3)
          IF(PHI(I,J,K).GT.CFLUX) THEN
            WRITE(HSMG,'(23HTHMTRS: THE HEAT FLUX (,1P,E12.4,5H) IS ,
     >      37HGREATER THAN THE CRITICAL HEAT FLUX (,E12.4,2H).)')
     >      PHI(I,J,K),CFLUX
            CALL XABORT(HSMG)
          ENDIF
*----
*  FLOW RATE CALCULATION WITH MASS CONSERVATION EQUATION
*----
          PARAM1=0.5*(DCOOLI(I,J,K)-DCOOL(I,J,K))*DTINV*HZ(K)
          IF(K.EQ.KMIN) THEN
            PARAM1=PARAM1+0.5*(RHOIN0-RHOINL)*DTINV*HZ(K)
            MFLXT(I,J,K)=MFLXIN+PARAM1
          ELSE
            PARAM1=PARAM1+0.5*(DCOOLI(I,J,K-1)-DCOOL(I,J,K-1))*DTINV
     >      *HZ(K)
            MFLXT(I,J,K)=MFLXT(I,J,K-1)+PARAM1
          ENDIF
*----
*  ENTHALPY VECTOR CALCULATION WITH ENERGY CONSERVATION EQUATION
*----
          PARAM1=0.5*DCOOL(I,J,K)*DTINV*HZ(K)+MFLXT(I,J,K)
          PARAM2=0.5*DCOOLI(I,J,K)*ENTHT0(I,J,K)*DTINV*HZ(K)
          PARAM3=(QCOOL(I,J,K)+PHI(I,J,K)*PCH/ACOOL)*HZ(K)
          IF(K.EQ.KMIN) THEN
            PARAM2=PARAM2+0.5*(RHOIN0*HINLE0-RHOINL*HINLET)*DTINV*HZ(K)
            PARAM2=PARAM2+MFLXIN*HINLET
            HMINF=HINLET
          ELSE
            PARAM2=PARAM2+0.5*(DCOOLI(I,J,K-1)*ENTHT0(I,J,K-1)-
     1      DCOOL(I,J,K-1)*ENTHT(I,J,K-1))*DTINV*HZ(K)
            PARAM2=PARAM2+MFLXT(I,J,K-1)*ENTHT(I,J,K-1)
            HMINF=ENTHT(I,J,K-1)
          ENDIF
          ENTHT(I,J,K)=(PARAM2+PARAM3)/PARAM1
          DELTH=ENTHT(I,J,K)-HMINF
*----
*  COMPUTE THE COOLANT TEMPERATURE AND THE OUTER CLADDING TEMPERATURE
*----
          DO I1=1,4
             POINT=(1.0+XS(I1))/2.0
             ENT(I1)=HMINF+POINT*DELTH
          ENDDO
          CALL THMH2O(I,J,K,PREST(I,J,K),MFLXT(I,J,K),EPS(K),ENT,
     1    PHI(I,J,K),HD,IHCONV,KHCONV,TL,DCOOL(I,J,K),DLIQT(I,J,K),
     2    HCONV(I,J,K),TRE11(NDTOT),XTH(K))
*
          RCHC=RAY(3)*HCONV(I,J,K)
          TRE11(NDTOT)=MAX(273.15,(ZF(1)+RCHC*TL)/(ZF(2)+RCHC))
          DO L=1,NDTOT-1
            TRE11(L)=XX2(L)+TRE11(NDTOT)*XX3(L)
            TEMPT(I,J,K,L)=TRE11(L)
          ENDDO
          TEMPT(I,J,K,NDTOT)=TRE11(NDTOT)
*----
*  RECOVER MESHWISE TEMPERATURES AND FLUID DENSITY. BY DEFAULT, USE THE
*  ROWLANDS FORMULA TO COMPUTE THE EFFECTIVE FUEL TEMPERATURE, OTHERWISE
*  USE USER-SPECIFIED WEIGHTING FACTOR.
*----
          TCOMB(I,J,K)=(1.0-WTEFF)*TC1+WTEFF*TRE11(NFD)
          TCOOL(I,J,K)=TL
          TCENTT(I,J,K)=TC1
          TSURF(I,J,K)=TRE11(NFD)
          TCLAD(I,J,K)=TRE11(NDTOT)
        ENDDO
*----
*  MOMENTUM VECTOR CALCULATION WITH MOMENTUM CONSERVATION EQUATION
*----
*        DO K=KC,1,-1
*          IF(POW(I,J,K).EQ.0.0) CYCLE
*          RET=ABS(MFLXT(I,J,K))*(1.0-XFL(K))*HD/MUT(I,J,K)
*          PARAM1=0.5*(MFLXT(I,J,K)-MFLXT0(I,J,K))*DTINV*HZ(K)
*          PARAM2=MFLXT(I,J,K)**2.0/DCOOL(I,J,K)
*          CALL THMFRI(RET,F)
*          IF(XFL(K).GT.0.0) THEN
*            CALL THMPLO(PREST(I,J,K),XFL(K),PHIL0)
*          ELSE
*            PHIL0=1.0
*          ENDIF
*          PARAM31=DCOOL(I,J,K)*PES
*          PARAM32=0.5*F*MFLXT(I,J,K)**2.0/HD/DLIQT0(I,J,K)*PHIL0
*          PARAM3=(PARAM31+PARAM32)*HZ(K)
*          IF(K.EQ.1) THEN
*            PARAM1=PARAM1+0.5*(MFLXIN-MFLXIN0)*DTINV*HZ(1)
*            PARAM2=PARAM2-MFLXIN**2.0/RHOINL
*            PREST(I,J,1)=PREST(I,J,2)+PARAM1+PARAM2+PARAM3
*          ELSE IF(K.LT.KC) THEN
*            PARAM1=PARAM1+0.5*(MFLXT(I,J,K-1)-MFLXT0(I,J,K-1))*DTINV*
*     1      HZ(K)
*            PARAM2=PARAM2-MFLXT(I,J,K-1)**2.0/DCOOL(I,J,K-1)
*            PREST(I,J,K)=PREST(I,J,K+1)+PARAM1+PARAM2+PARAM3
*          ELSE IF(K.EQ.KC) THEN
*            PARAM1=PARAM1+0.5*(MFLXT(I,J,KC-1)-MFLXT0(I,J,KC-1))*DTINV*
*     1      HZ(KC)
*            PARAM2=PARAM2-MFLXT(I,J,K-1)**2.0/DCOOL(I,J,K-1)
*            PREST(I,J,KC)=POULET+PARAM1+PARAM2+PARAM3
*          ENDIF
*        ENDDO
        PINLET=PREST(I,J,KMIN)
*----
*  CALCULATE THE VOID FRACTION COEFFICIENT AND THE STEAM QUALITY
*----
        DO K=1,KC
          IF(POW(I,J,K).EQ.0.0) THEN
            VC(K)=SPDIN
            SAH(K)=0.0
          ELSE
            VC(K)=MFLXT(I,J,K)/DCOOL(I,J,K)
            SAH(K)=154.0*PHI(I,J,K)/MFLXT(I,J,K) ! Saha-Zuber correlation
          ENDIF
          HZC(K)=HZ(K)
          PHIC(K)=PHI(I,J,K)
          TP(K)=TCLAD(I,J,K)
          TLC(K)=TCOOL(I,J,K)
          HC(K)=HCONV(I,J,K)
          ENTH(K)=ENTHT(I,J,K)    
          AGM(K)=MFLXT(I,J,K)
          PC(K)=PREST(I,J,K)
        ENDDO
*       compute the distribution of void fraction and steam flow
*       quality along the channel
        IF(ISUBM.EQ.1) THEN
*         Jens-Lottes correlation and Bowring's model
          CALL THMJLB(KC,HZC,VC,PC,PHIC,TP,TLC,HC,S,XFL,EPS)
        ELSE IF(ISUBM.EQ.2) THEN
*         Saha-Zuber subcooling model
          CALL THMJLC(KC,AGM,ENTH,SAH,ACOOL,PC,S,XFL,EPS)
        ELSE IF(ISUBM.NE.0) THEN
          CALL XABORT('THMTRS: UNKNOWN SUBCOOLING MODEL.')
        ENDIF
*----
*  COMPUTE NEW VALUES OF DENSITIES AND VELOCITIES OVER CHANNEL
*----
         DO K=1,KC
           IF(EPS(K).GT.0.0) THEN
             CALL THMSAT(PREST(I,J,K),TSAT)
             CALL THMTX(TSAT,1.0,RGSAT,HGSAT)
             DCOOL(I,J,K)=DLIQT(I,J,K)*(1.0-EPS(K))+EPS(K)*RGSAT
           ELSE
             DCOOL(I,J,K)=DLIQT(I,J,K)
           ENDIF
           VELOT(I,J,K)=MFLXT(I,J,K)/DCOOL(I,J,K)
         ENDDO
*----
*  CONVERGENCE TEST FOR THE ENTHALPY, PRESSURE DENSITY AND
*  MASS FLUX CALCULATION.
*----
        ERRG=0.0
        ERRP=0.0
        ERRH=0.0
        ERR=0.0
        ERX=0.0
        DO K=1,KC
          IF(POW(I,J,K).EQ.0.0) CYCLE
          CALL THMSAT(PREST(I,J,K),TSAT)
          TB=TSAT-0.1
          IF(TCOOL(I,J,K).LT.TB) THEN
             CALL THMPT(PREST(I,J,K),TCOOL(I,J,K),R11,H11,K11,
     1       MUT(I,J,K),C11)
          ELSE
             CALL THMPT(PREST(I,J,K),TB,R11,H11,K11,MUT(I,J,K),C11)
          ENDIF
          ERRG=MAX(ERRG,ABS(MFLXT(I,J,K)-RESM(I,J,K))/MFLXT(I,J,K))
          ERRP=MAX(ERRP,ABS(PREST(I,J,K)-RESP(I,J,K))/PREST(I,J,K))
          ERRH=MAX(ERRH,ABS(ENTHT(I,J,K)-RESH(I,J,K))/ENTHT(I,J,K))
          RESM(I,J,K)=MFLXT(I,J,K)
          RESP(I,J,K)=PREST(I,J,K)
          RESH(I,J,K)=ENTHT(I,J,K)
        ENDDO
        ERR=MAX(ERRG,ERRP,ERRH)
        IF(IMPX.GT.1) WRITE(6,200) ITERC,ERRG,ERRP,ERRH
        CALL THMPT(PINLET,TINLET,RHOINL,HINLET,R3,MUIN,CPVIN)
        IF((ERR.LT.ERMAXC).AND.(ITERC.GT.1)) THEN
          GO TO 30
        ELSE
          GO TO 20
        ENDIF
*----
*  PRINT THE OUTLET THERMOHYDRAULICAL PARAMETERS
*----
   30   IF(IMPX.GT.3) THEN
           WRITE(6,'(/16H THMTRS: CHANNEL,2I6/1X,27(1H-))') I,J
           WRITE(6,210) ' ___________________________________________',
     >          '____________________________________________________',
     >          '____________________________________________________',
     >          '______________________'
           WRITE(6,210) '|     |   TFUEL    |   TSURF    |    MFLXT  ',
     >          '  |    DCOOL    |    TCOOL    |    PCOOL    |    HCO',
     >          'OL    |    QFUEL    |    QCOOL    |    VOID   |     ',
     >          'QUAL    |     SLIP    |','|     |     K      |     K',
     >          '      |   Kg/m2/s   |    Kg/m3    |      K      |   ',
     >          '  Pa      |    J/Kg     |    W/m3     |    W/m3     ',
     >          '|           |             |             |'
           WRITE(6,210) '|_____|____________|____________|___________',
     >          '__|_____________|_____________|_____________|_______',
     >          '______|_____________|_____________|___________|_____',
     >          '________|_____________|'
           DO L=KC,1,-1
             IF(L.EQ.1) THEN
               WRITE(6,220) '| BOT |',TCOMB(I,J,L),' |',TSURF(I,J,L),
     >            ' |',MFLXT(I,J,L),' |',DCOOL(I,J,L),' |',TCOOL(I,J,L),
     >            ' |',PREST(I,J,L),' |',ENTHT(I,J,L),' |',QFUEL(I,J,L),
     >            ' |',QCOOL(I,J,L),' |',EPS(L),' |',XFL(L),' |',S(L),
     >            ' |'
             ELSEIF(L.EQ.KC) THEN
               WRITE(6,220) '| TOP |',TCOMB(I,J,L),' |',TSURF(I,J,L),
     >            ' |',MFLXT(I,J,L),' |',DCOOL(I,J,L),' |',TCOOL(I,J,L),
     >            ' |',PREST(I,J,L),' |',ENTHT(I,J,L),' |',QFUEL(I,J,L),
     >            ' |',QCOOL(I,J,L),' |',EPS(L),' |',XFL(L),' |',S(L),
     >            ' |'
             ELSE
               WRITE(6,225) '| ',L,' |',TCOMB(I,J,L),' |',TSURF(I,J,L),
     >            ' |',MFLXT(I,J,L),' |',DCOOL(I,J,L),' |',TCOOL(I,J,L),
     >            ' |',PREST(I,J,L),' |',ENTHT(I,J,L),' |',QFUEL(I,J,L),
     >            ' |',QCOOL(I,J,L),' |',EPS(L),' |',XFL(L),' |',S(L),
     >            ' |'
             ENDIF
           ENDDO
           WRITE(6,210) '|_____|____________|____________|___________',
     >          '__|_____________|_____________|_____________|_______',
     >          '______|_____________|_____________|___________|_____',
     >          '________|_____________|'

        ENDIF
      ENDIF
*----
*  END OF LOOP OVER REACTOR CHANNELS
*----
   50 CONTINUE
      RETURN
*
  200 FORMAT(/24H THMTRS: FLOW ITERATION=,I5,1P,8H  ERROR=,3E12.4)
  210 FORMAT(1X,A,A,A,A)
  220 FORMAT(1X,A,F11.2,A,F11.2,A,F12.4,A,F12.4,A,F12.2,A,3P,E12.4,
     >       A,1P,E12.4,A,1P,E12.4,A,1P,E12.4,A,0P,F10.4,A,E12.4,A,
     >       E12.4,A)
  225 FORMAT(1X,A,I3,A,F11.2,A,F11.2,A,F12.4,A,F12.4,A,F12.2,A,3P,
     >       E12.4,A,1P,E12.4,A,1P,E12.4,A,1P,E12.4,A,0P,F10.4,A,
     >       E12.4,A,E12.4,A)
      END
